@@ -8,18 +8,23 @@ import copy
 import six
 
 import sina.sjson as json
+import sina.proxies
 
 logging.basicConfig()
 LOGGER = logging.getLogger(__name__)
 RESERVED_TYPES = ["run"]  # Types reserved by Record's children
 
 
+# Disable this check temporarily. Need to move some classes to another
+# location, but that is well out of scope for the current task.
+# pylint: disable=too-many-lines
+
 # Disable redefined-builtin, invalid-name due to ubiquitous use of id and type
 # pylint: disable=invalid-name,redefined-builtin
 
 # We don't mind the high instance attribute count since this is essentially
-# a reflection of our schema.
-class Record(object):  # pylint: disable=too-many-instance-attributes
+# a reflection of our schema. Similarly, we need a fair few methods for all those attribs.
+class Record(object):  # pylint: disable=too-many-instance-attributes, too-many-public-methods
     """
     A record is any arbitrary object we've chosen to store.
 
@@ -92,6 +97,14 @@ class Record(object):  # pylint: disable=too-many-instance-attributes
     def data(self, data):
         self['data'] = data
 
+    @property
+    def data_values(self):
+        """
+        Get a :py:class:`sina.proxies.ValueProxy` object that gives direct
+        access to the "value" objects of the "data" dictionary on this record.
+        """
+        return sina.proxies.ValueProxy(self['data'])
+
     @property
     def curve_sets(self):
         """Get or set the Record's curve dictionary."""
@@ -123,6 +136,14 @@ class Record(object):  # pylint: disable=too-many-instance-attributes
         except KeyError:
             raise AttributeError('Record "{}" has no curve set "{}"'.format(self.id, name))
 
+    @property
+    def curve_set_values(self):
+        """
+        Get a :py:class:`sina.proxies.CurveSetProxy` object that gives direct
+        access to the "value" objects of curves sets in this record.
+        """
+        return sina.proxies.CurveSetProxy(self.raw['curve_sets'])
+
     @property
     def library_data(self):
         """Get or set the Record's data dictionary."""
@@ -132,6 +153,15 @@ class Record(object):  # pylint: disable=too-many-instance-attributes
     def library_data(self, library_data):
         self['library_data'] = library_data
 
+    @property
+    def library_data_values(self):
+        """
+        Get a :py:class:`sina.proxies.LibraryValuesProxy` object that gives
+        access to the "value" objects of data and curves sets in the
+        library sections of this record.
+        """
+        return sina.proxies.LibraryValuesProxy(self.library_data)
+
     @property
     def files(self):
         """Get or set the Record's file list."""
@@ -312,6 +342,26 @@ class Record(object):  # pylint: disable=too-many-instance-attributes
         """
         return json.dumps(self.raw)
 
+    def to_file(self, path):
+        """
+        Dump the JSON form of this Record to a file as a Sina Document.
+
+        This creates Sina Document object, aka the JSON container
+        that holds Records and Relationships, containing only this Record.
+
+        It's often the case that a json (especially those output as part of simulations)
+        contains exactly one Record and zero Relationships. This function is a
+        convenience method to aid in post-processing that common file type.
+
+        :param path: The path to the file to be created. Note that the contents,
+                     if any, will be replaced. This is intended, as this function
+                     acts as the filesystem equivalent of the datastore-side update().
+        """
+        with open(path, "wb") as outpath:
+            content = {"records": [self.raw], "relationships": []}
+            # Note the use of dumps()--that's because orjson doesn't have dump()
+            outpath.write(json.dumps(content, outpath))
+
     def _library_data_is_valid(self, library_data, prefix=""):
         """
         Test whether library data is valid.
@@ -759,11 +809,11 @@ class Run(Record):
 
     def __repr__(self):
         """Return a string representation of a model Run."""
-        return('Model Run <id={}, application={}, user={}, version={}>'
-               .format(self.id,
-                       self.application,
-                       self.user,
-                       self.version))
+        return 'Model Run <id={}, application={}, user={}, version={}>'.format(
+            self.id,
+            self.application,
+            self.user,
+            self.version)
 
 
 def _is_valid_list(list_of_data):
